@@ -1,5 +1,5 @@
 package Text::ANSI::Tabs;
-our $VERSION = "1.0501";
+our $VERSION = "1.06";
 
 =encoding utf-8
 
@@ -20,7 +20,7 @@ Text::ANSI::Tabs - Tab expand and unexpand with ANSI sequence
 
 =head1 VERSION
 
-Version 1.0501
+Version 1.06
 
 =cut
 
@@ -74,12 +74,20 @@ sub configure {
     return $fold;
 }
 
+sub IsEOL {
+    <<"END";
+0000\t0000
+000A\t000D
+2028\t2029
+END
+}
+
 sub expand {
-    my @opt = ref $_[0] eq 'ARRAY' ? @{+shift} : ();
-    my @param = (width => -1, expand => 1, tabstop => $tabstop, @opt);
+    $fold->configure(width => -1, expand => 1, tabstop => $tabstop,
+		     ref $_[0] eq 'ARRAY' ? @{+shift} : ());
     my @l = map {
 	s{^ (?>.*\t) (?: [^\e\n]* $end_re+ )? }{
-	    ($fold->fold(${^MATCH}, @param))[0];
+	    join '', $fold->text(${^MATCH})->chops();
 	}xmgepr;
     } @_;
     wantarray ? @l : $l[0];
@@ -123,6 +131,10 @@ __END__
 
 ANSI sequence and Unicode wide characters aware version of Text::Tabs.
 
+It assumes that the ANSI decolation is completed within a single line,
+and cannot correctly process data where the effect continues over
+multiple lines.
+
 =head1 FUNCTION
 
 There are exportable functions start with C<ansi_> prefix, and
